// clock.h
// VERSION 2
// Glenn G. Chappell
// 12 Sep 2013
// Header for class Clock
// Holds a time of day in seconds

#ifndef CLOCK_H  // Always do this in a C++ header; the name of
#define CLOCK_H  //  the constant should be based on the filename

#include <iostream>
using std::cout;
using std::ostream;


// class Clock
// Holds a time of day: hours, minutes, seconds.
// Includes printing capability.
//
// Class invariants:
//    0 <= _hr; _hr < 24
//    0 <= _min; _min < 60
//    0 <= _sec; _sec < 60
class Clock {

// ***** Clock: Ctors, dctor *****
public:

    // Ctor
    // Set time to given hr/min/sec.
    // 0-param version sets time to midnight.
    // 1-param sets time to the given hour.
    // 2-param sets time to given hour & minute.
    // 3-param sets all three.
    Clock(int hr=0, int min=0, int sec=0)
    {
        setTime(hr, min, sec);
    }

    // Compiler-generated dctor used

// ***** Clock: General public functions *****
public:

    // setTime
    // Set time to given hr/min/sec.
    // 0-param version sets time to midnight.
    // 1-param sets time to the given hour.
    // 2-param sets time to given hour & minute.
    // 3-param sets all three.
    void setTime(int hr=0, int min=0, int sec=0)
    {
        setHr(hr);
        setMin(min);
        setSec(sec);
    }

    // Get & set functions for _hr member
    // The set function ensures that the member is within range
    int getHr() const
    {
        return _hr;
    }
    void setHr(int hr)
    {
        if (hr < 0 || hr > 23)
            hr = 0;
        _hr = hr;
    }

    // Get & set functions for _min member
    // The set function ensures that the member is within range
    int getMin() const
    {
        return _min;
    }
    void setMin(int min)
    {
        if (min < 0 || min > 59)
            min = 0;
        _min = min;
    }

    // Get & set functions for _sec member
    // The set function ensures that the member is within range
    int getSec() const
    {
        return _sec;
    }
    void setSec(int sec)
    {
        if (sec < 0 || sec > 59)
            sec = 0;
        _sec = sec;
    }

    // print
    // Output time held by object to given stream as hh:mm:ss, 24-hour
    //  time, hh padded with blanks, mm & ss padded with '0'. No
    //  trailing newline is printed.
    void print(ostream & outstr=cout) const;

    // Member function print is defined in the associated source file

// ***** Clock: Data members *****
private:

    int _hr;   // Hours past midnight (0 .. 23)
    int _min;  // Minutes past the hour (0 .. 59)
    int _sec;  // Seconds past the minute (0 .. 59)

};  // End class Clock

#endif // #ifndef CLOCK_H

